==> skywalking-nodejs-src-0.3.0.tgz: src/proto/service-mesh-probe/service-mesh_grpc_pb.d.ts <==
// package: 
// file: service-mesh-probe/service-mesh.proto

/* tslint:disable */
/* eslint-disable */

import * as grpc from "grpc";
import * as service_mesh_probe_service_mesh_pb from "../service-mesh-probe/service-mesh_pb";
import * as common_Common_pb from "../common/Common_pb";

interface IServiceMeshMetricServiceService extends grpc.ServiceDefinition<grpc.UntypedServiceImplementation> {
    collect: IServiceMeshMetricServiceService_Icollect;
}

interface IServiceMeshMetricServiceService_Icollect extends grpc.MethodDefinition<service_mesh_probe_service_mesh_pb.ServiceMeshMetric, service_mesh_probe_service_mesh_pb.MeshProbeDownstream> {
    path: "/ServiceMeshMetricService/collect";
    requestStream: true;
    responseStream: false;
    requestSerialize: grpc.serialize<service_mesh_probe_service_mesh_pb.ServiceMeshMetric>;
    requestDeserialize: grpc.deserialize<service_mesh_probe_service_mesh_pb.ServiceMeshMetric>;
    responseSerialize: grpc.serialize<service_mesh_probe_service_mesh_pb.MeshProbeDownstream>;
    responseDeserialize: grpc.deserialize<service_mesh_probe_service_mesh_pb.MeshProbeDownstream>;
}

export const ServiceMeshMetricServiceService: IServiceMeshMetricServiceService;

export interface IServiceMeshMetricServiceServer {
    collect: grpc.handleClientStreamingCall<service_mesh_probe_service_mesh_pb.ServiceMeshMetric, service_mesh_probe_service_mesh_pb.MeshProbeDownstream>;
}

export interface IServiceMeshMetricServiceClient {
    collect(callback: (error: grpc.ServiceError | null, response: service_mesh_probe_service_mesh_pb.MeshProbeDownstream) => void): grpc.ClientWritableStream<service_mesh_probe_service_mesh_pb.ServiceMeshMetric>;
    collect(metadata: grpc.Metadata, callback: (error: grpc.ServiceError | null, response: service_mesh_probe_service_mesh_pb.MeshProbeDownstream) => void): grpc.ClientWritableStream<service_mesh_probe_service_mesh_pb.ServiceMeshMetric>;
    collect(options: Partial<grpc.CallOptions>, callback: (error: grpc.ServiceError | null, response: service_mesh_probe_service_mesh_pb.MeshProbeDownstream) => void): grpc.ClientWritableStream<service_mesh_probe_service_mesh_pb.ServiceMeshMetric>;
    collect(metadata: grpc.Metadata, options: Partial<grpc.CallOptions>, callback: (error: grpc.ServiceError | null, response: service_mesh_probe_service_mesh_pb.MeshProbeDownstream) => void): grpc.ClientWritableStream<service_mesh_probe_service_mesh_pb.ServiceMeshMetric>;
}

export class ServiceMeshMetricServiceClient extends grpc.Client implements IServiceMeshMetricServiceClient {
    constructor(address: string, credentials: grpc.ChannelCredentials, options?: object);
    public collect(callback: (error: grpc.ServiceError | null, response: service_mesh_probe_service_mesh_pb.MeshProbeDownstream) => void): grpc.ClientWritableStream<service_mesh_probe_service_mesh_pb.ServiceMeshMetric>;
    public collect(metadata: grpc.Metadata, callback: (error: grpc.ServiceError | null, response: service_mesh_probe_service_mesh_pb.MeshProbeDownstream) => void): grpc.ClientWritableStream<service_mesh_probe_service_mesh_pb.ServiceMeshMetric>;
    public collect(options: Partial<grpc.CallOptions>, callback: (error: grpc.ServiceError | null, response: service_mesh_probe_service_mesh_pb.MeshProbeDownstream) => void): grpc.ClientWritableStream<service_mesh_probe_service_mesh_pb.ServiceMeshMetric>;
    public collect(metadata: grpc.Metadata, options: Partial<grpc.CallOptions>, callback: (error: grpc.ServiceError | null, response: service_mesh_probe_service_mesh_pb.MeshProbeDownstream) => void): grpc.ClientWritableStream<service_mesh_probe_service_mesh_pb.ServiceMeshMetric>;
}

==> skywalking-nodejs-src-0.4.0.tgz: src/proto/service-mesh-probe/service-mesh_grpc_pb.d.ts <==
// package: 
// file: service-mesh-probe/service-mesh.proto

/* tslint:disable */
/* eslint-disable */

import * as grpc from "@grpc/grpc-js";
import * as service_mesh_probe_service_mesh_pb from "../service-mesh-probe/service-mesh_pb";
import * as common_Common_pb from "../common/Common_pb";

interface IServiceMeshMetricServiceService extends grpc.ServiceDefinition<grpc.UntypedServiceImplementation> {
    collect: IServiceMeshMetricServiceService_Icollect;
}

interface IServiceMeshMetricServiceService_Icollect extends grpc.MethodDefinition<service_mesh_probe_service_mesh_pb.ServiceMeshMetric, service_mesh_probe_service_mesh_pb.MeshProbeDownstream> {
    path: "/ServiceMeshMetricService/collect";
    requestStream: true;
    responseStream: false;
    requestSerialize: grpc.serialize<service_mesh_probe_service_mesh_pb.ServiceMeshMetric>;
    requestDeserialize: grpc.deserialize<service_mesh_probe_service_mesh_pb.ServiceMeshMetric>;
    responseSerialize: grpc.serialize<service_mesh_probe_service_mesh_pb.MeshProbeDownstream>;
    responseDeserialize: grpc.deserialize<service_mesh_probe_service_mesh_pb.MeshProbeDownstream>;
}

export const ServiceMeshMetricServiceService: IServiceMeshMetricServiceService;

export interface IServiceMeshMetricServiceServer extends grpc.UntypedServiceImplementation {
    collect: grpc.handleClientStreamingCall<service_mesh_probe_service_mesh_pb.ServiceMeshMetric, service_mesh_probe_service_mesh_pb.MeshProbeDownstream>;
}

export interface IServiceMeshMetricServiceClient {
    collect(callback: (error: grpc.ServiceError | null, response: service_mesh_probe_service_mesh_pb.MeshProbeDownstream) => void): grpc.ClientWritableStream<service_mesh_probe_service_mesh_pb.ServiceMeshMetric>;
    collect(metadata: grpc.Metadata, callback: (error: grpc.ServiceError | null, response: service_mesh_probe_service_mesh_pb.MeshProbeDownstream) => void): grpc.ClientWritableStream<service_mesh_probe_service_mesh_pb.ServiceMeshMetric>;
    collect(options: Partial<grpc.CallOptions>, callback: (error: grpc.ServiceError | null, response: service_mesh_probe_service_mesh_pb.MeshProbeDownstream) => void): grpc.ClientWritableStream<service_mesh_probe_service_mesh_pb.ServiceMeshMetric>;
    collect(metadata: grpc.Metadata, options: Partial<grpc.CallOptions>, callback: (error: grpc.ServiceError | null, response: service_mesh_probe_service_mesh_pb.MeshProbeDownstream) => void): grpc.ClientWritableStream<service_mesh_probe_service_mesh_pb.ServiceMeshMetric>;
}

export class ServiceMeshMetricServiceClient extends grpc.Client implements IServiceMeshMetricServiceClient {
    constructor(address: string, credentials: grpc.ChannelCredentials, options?: Partial<grpc.ClientOptions>);
    public collect(callback: (error: grpc.ServiceError | null, response: service_mesh_probe_service_mesh_pb.MeshProbeDownstream) => void): grpc.ClientWritableStream<service_mesh_probe_service_mesh_pb.ServiceMeshMetric>;
    public collect(metadata: grpc.Metadata, callback: (error: grpc.ServiceError | null, response: service_mesh_probe_service_mesh_pb.MeshProbeDownstream) => void): grpc.ClientWritableStream<service_mesh_probe_service_mesh_pb.ServiceMeshMetric>;
    public collect(options: Partial<grpc.CallOptions>, callback: (error: grpc.ServiceError | null, response: service_mesh_probe_service_mesh_pb.MeshProbeDownstream) => void): grpc.ClientWritableStream<service_mesh_probe_service_mesh_pb.ServiceMeshMetric>;
    public collect(metadata: grpc.Metadata, options: Partial<grpc.CallOptions>, callback: (error: grpc.ServiceError | null, response: service_mesh_probe_service_mesh_pb.MeshProbeDownstream) => void): grpc.ClientWritableStream<service_mesh_probe_service_mesh_pb.ServiceMeshMetric>;
}
